@@ -1,3 +1,4 @@
+import os
 import matplotlib
 import matplotlib.pyplot as plt
 import matplotlib.collections as mc
@@ -86,9 +87,9 @@ def plot_graph(vcoords, ecoords, plotpath, shppath=''):
 def plot_igraph(gin, plotpath, shppath=''):
     """Plot the graph @gin and export to @plotpath and, if provided, plot
     the border given by @shppath"""
-    import graph
+    from .graph import simplify_graphml
     if type(gin) == str:
-        g = graph.simplify_graphml(gin, directed=False, simplify=True)
+        g = simplify_graphml(gin, directed=False, simplify=True)
     else:
         g = gin
 
